@@ -19,7 +19,7 @@ from oslo_config import cfg
 from oslo_log import log as logging
 from oslo_utils import excutils
 
-from neutron_lbaas._i18n import _, _LE
+from neutron_lbaas._i18n import _
 
 
 LOG = logging.getLogger(__name__)
@@ -28,7 +28,6 @@ _SESSION = None
 OPTS = [
     cfg.StrOpt(
         'auth_url',
-        default='http://127.0.0.1:5000/v2.0',
         help=_('Authentication endpoint'),
     ),
     cfg.StrOpt(
@@ -69,7 +68,7 @@ OPTS = [
     ),
     cfg.StrOpt(
         'auth_version',
-        default='2',
+        default='3',
         help=_('The auth version used to authenticate'),
     ),
     cfg.StrOpt(
@@ -120,6 +119,6 @@ def get_session():
             _SESSION = session.Session(auth=kc, verify=not insecure)
         except Exception:
             with excutils.save_and_reraise_exception():
-                LOG.exception(_LE("Error creating Keystone session."))
+                LOG.exception("Error creating Keystone session.")
 
     return _SESSION
