@@ -21,13 +21,14 @@ import netaddr
 from neutron.agent.linux import external_process
 from neutron.agent.linux import ip_lib
 from neutron.common import utils as n_utils
-from neutron.plugins.common import constants
+from neutron_lib import constants
 from neutron_lib import exceptions
+from neutron_lib.utils import runtime
 from oslo_config import cfg
 from oslo_log import log as logging
 from oslo_utils import excutils
 
-from neutron_lbaas._i18n import _, _LI, _LW
+from neutron_lbaas._i18n import _
 from neutron_lbaas.agent import agent_device_driver
 from neutron_lbaas.drivers.haproxy import jinja_cfg
 from neutron_lbaas.services.loadbalancer import constants as lb_const
@@ -84,7 +85,7 @@ class HaproxyNSDriver(agent_device_driver.AgentDeviceDriver):
         self.state_path = os.path.join(
             self.conf.haproxy.loadbalancer_state_path, STATE_PATH_V2_APPEND)
         try:
-            vif_driver_class = n_utils.load_class_by_alias_or_classname(
+            vif_driver_class = runtime.load_class_by_alias_or_classname(
                 'neutron.interface_drivers',
                 conf.interface_driver)
         except ImportError:
@@ -124,7 +125,7 @@ class HaproxyNSDriver(agent_device_driver.AgentDeviceDriver):
     def get_name(self):
         return DRIVER_NAME
 
-    @n_utils.synchronized('haproxy-driver')
+    @runtime.synchronized('haproxy-driver')
     def undeploy_instance(self, loadbalancer_id, **kwargs):
         cleanup_namespace = kwargs.get('cleanup_namespace', False)
         delete_namespace = kwargs.get('delete_namespace', False)
@@ -184,18 +185,26 @@ class HaproxyNSDriver(agent_device_driver.AgentDeviceDriver):
             lb_stats['members'] = self._get_servers_stats(parsed_stats)
             return lb_stats
         else:
-            LOG.warning(_LW('Stats socket not found for loadbalancer %s'),
-                        loadbalancer_id)
+            lb_config = self.plugin_rpc.get_loadbalancer(loadbalancer_id)
+            loadbalancer = data_models.LoadBalancer.from_dict(lb_config)
+            if self._is_active(loadbalancer):
+                LOG.warning('Stats socket not found for loadbalancer %s',
+                            loadbalancer_id)
+            else:
+                LOG.debug('Stats socket not found for loadbalancer %s,'
+                          ' but loadbalancer has no VIP in state UP.'
+                          ' Perhaps the lbaas-listener is not yet created?',
+                          loadbalancer_id)
             return {}
 
-    @n_utils.synchronized('haproxy-driver')
+    @runtime.synchronized('haproxy-driver')
     def deploy_instance(self, loadbalancer):
         """Deploys loadbalancer if necessary
 
         :returns: True if loadbalancer was deployed, False otherwise
         """
         if not self.deployable(loadbalancer):
-            LOG.info(_LI("Loadbalancer %s is not deployable.") %
+            LOG.info("Loadbalancer %s is not deployable." %
                      loadbalancer.id)
             return False
 
@@ -247,18 +256,18 @@ class HaproxyNSDriver(agent_device_driver.AgentDeviceDriver):
         try:
             s = socket.socket(socket.AF_UNIX, socket.SOCK_STREAM)
             s.connect(socket_path)
-            s.send('show stat -1 %s -1\n' % entity_type)
+            s.send(('show stat -1 %s -1\n' % entity_type).encode('utf-8'))
             raw_stats = ''
             chunk_size = 1024
             while True:
-                chunk = s.recv(chunk_size)
+                chunk = s.recv(chunk_size).decode('utf-8')
                 raw_stats += chunk
                 if len(chunk) < chunk_size:
                     break
 
             return self._parse_stats(raw_stats)
         except socket.error as e:
-            LOG.warning(_LW('Error while connecting to stats socket: %s'), e)
+            LOG.warning('Error while connecting to stats socket: %s', e)
             return {}
 
     def _parse_stats(self, raw_stats):
@@ -416,6 +425,15 @@ class HaproxyNSDriver(agent_device_driver.AgentDeviceDriver):
         # remember deployed loadbalancer id
         self.deployed_loadbalancers[loadbalancer.id] = loadbalancer
 
+    def _is_active(self, loadbalancer):
+        # haproxy will be unable to start without any active vip
+        if (len(loadbalancer.listeners) == 0 or
+                loadbalancer.vip_port.status == constants.DOWN or
+                not loadbalancer.vip_port.admin_state_up or
+                loadbalancer.operating_status != lb_const.ONLINE):
+            return False
+        return True
+
 
 class LoadBalancerManager(agent_device_driver.BaseLoadBalancerManager):
 
