@@ -17,13 +17,13 @@ import abc
 
 from neutron_lib.api import extensions as api_extensions
 from neutron_lib import exceptions as nexception
+from neutron_lib.plugins import constants as plugin_const
 from neutron_lib.plugins import directory
 
 from neutron.api import extensions
 from neutron.api.v2 import base
 from neutron.api.v2 import resource
 from neutron.extensions import agent
-from neutron.plugins.common import constants as plugin_const
 from neutron import policy
 from neutron import wsgi
 
@@ -81,10 +81,6 @@ class Lbaas_agentschedulerv2(api_extensions.ExtensionDescriptor):
     def get_description(cls):
         return "Schedule load balancers among lbaas agents"
 
-    @classmethod
-    def get_namespace(cls):
-        return "http://docs.openstack.org/ext/lbaas_agent_scheduler/api/v1.0"
-
     @classmethod
     def get_updated(cls):
         return "2013-02-07T10:00:00-00:00"
