@@ -15,25 +15,24 @@
 
 import copy
 
+from neutron_lib import context as ncontext
 from neutron_lib.plugins import directory
 
 from neutron.api.v2 import attributes as attrs
 from neutron.api.v2 import base as napi_base
-from neutron import context as ncontext
 from neutron.db import agentschedulers_db
 from neutron.db import servicetype_db as st_db
 from neutron.extensions import flavors
-from neutron.plugins.common import constants
 from neutron import service
 from neutron.services.flavors import flavors_plugin
 from neutron.services import provider_configuration as pconf
 from neutron.services import service_base
 from neutron_lib import constants as n_constants
 from neutron_lib import exceptions as n_exc
+from neutron_lib.plugins import constants
 from oslo_log import log as logging
 from oslo_utils import encodeutils
 
-from neutron_lbaas._i18n import _LI, _LE
 from neutron_lbaas import agent_scheduler as agent_scheduler_v2
 import neutron_lbaas.common.cert_manager
 from neutron_lbaas.common.tls_utils import cert_parser
@@ -127,8 +126,8 @@ class LoadBalancerPluginv2(loadbalancerv2.LoadBalancerPluginBaseV2,
              if lb.provider.provider_name not in provider_names])
         # resources are left without provider - stop the service
         if lost_providers:
-            msg = _LE("Delete associated load balancers before "
-                      "removing providers %s") % list(lost_providers)
+            msg = ("Delete associated load balancers before "
+                   "removing providers %s") % list(lost_providers)
             LOG.error(msg)
             raise SystemExit(1)
 
@@ -137,8 +136,8 @@ class LoadBalancerPluginv2(loadbalancerv2.LoadBalancerPluginBaseV2,
             return self.drivers[provider]
         except KeyError:
             # raise if not associated (should never be reached)
-            raise n_exc.Invalid(_LE("Error retrieving driver for provider "
-                                    "%s") % provider)
+            raise n_exc.Invalid(_("Error retrieving driver for provider %s") %
+                                provider)
 
     def _get_driver_for_loadbalancer(self, context, loadbalancer_id):
         lb = self.db.get_loadbalancer(context, loadbalancer_id)
@@ -146,8 +145,8 @@ class LoadBalancerPluginv2(loadbalancerv2.LoadBalancerPluginBaseV2,
             return self.drivers[lb.provider.provider_name]
         except KeyError:
             raise n_exc.Invalid(
-                _LE("Error retrieving provider for load balancer. Possible "
-                    "providers are %s.") % self.drivers.keys()
+                _("Error retrieving provider for load balancer. Possible "
+                 "providers are %s.") % self.drivers.keys()
             )
 
     def _get_provider_name(self, entity):
@@ -169,7 +168,7 @@ class LoadBalancerPluginv2(loadbalancerv2.LoadBalancerPluginBaseV2,
                                old_db_entity=None, **kwargs):
         manager_method = "%s.%s" % (driver_method.__self__.__class__.__name__,
                                     driver_method.__name__)
-        LOG.info(_LI("Calling driver operation %s") % manager_method)
+        LOG.info("Calling driver operation %s" % manager_method)
         try:
             if old_db_entity:
                 driver_method(context, old_db_entity, db_entity, **kwargs)
@@ -180,14 +179,14 @@ class LoadBalancerPluginv2(loadbalancerv2.LoadBalancerPluginBaseV2,
                 lbaas_agentschedulerv2.NoActiveLbaasAgent) as no_agent:
             raise no_agent
         except Exception as e:
-            LOG.exception(_LE("There was an error in the driver"))
+            LOG.exception("There was an error in the driver")
             self._handle_driver_error(context, db_entity)
             raise loadbalancerv2.DriverError(msg=e)
 
     def _handle_driver_error(self, context, db_entity):
         lb_id = db_entity.root_loadbalancer.id
         self.db.update_status(context, models.LoadBalancer, lb_id,
-                              constants.ERROR)
+                              n_constants.ERROR)
 
     def _validate_session_persistence_info(self, sp_info):
         """Performs sanity check on session persistence info.
@@ -378,7 +377,12 @@ class LoadBalancerPluginv2(loadbalancerv2.LoadBalancerPluginBaseV2,
         create_method = (driver.load_balancer.create_and_allocate_vip
                          if driver.load_balancer.allocates_vip
                          else driver.load_balancer.create)
-        self._call_driver_operation(context, create_method, lb_db)
+        try:
+            self._call_driver_operation(context, create_method, lb_db)
+        except (lbaas_agentschedulerv2.NoEligibleLbaasAgent,
+                lbaas_agentschedulerv2.NoActiveLbaasAgent) as no_agent:
+            self.db.delete_loadbalancer(context, lb_db.id)
+            raise no_agent
         return self.db.get_loadbalancer(context, lb_db.id).to_api_dict()
 
     def create_graph(self, context, graph):
@@ -409,7 +413,7 @@ class LoadBalancerPluginv2(loadbalancerv2.LoadBalancerPluginBaseV2,
         loadbalancer = loadbalancer.get('loadbalancer')
         old_lb = self.db.get_loadbalancer(context, id)
         self.db.test_and_set_status(context, models.LoadBalancer, id,
-                                    constants.PENDING_UPDATE)
+                                    n_constants.PENDING_UPDATE)
         try:
             updated_lb = self.db.update_loadbalancer(
                 context, id, loadbalancer)
@@ -436,7 +440,7 @@ class LoadBalancerPluginv2(loadbalancerv2.LoadBalancerPluginBaseV2,
                 id=old_lb.pools[0].id,
                 entity_in_use=models.LoadBalancer.NAME)
         self.db.test_and_set_status(context, models.LoadBalancer, id,
-                                    constants.PENDING_DELETE)
+                                    n_constants.PENDING_DELETE)
         driver = self._get_driver_for_provider(old_lb.provider.provider_name)
         db_lb = self.db.get_loadbalancer(context, id)
         self._call_driver_operation(
@@ -502,7 +506,7 @@ class LoadBalancerPluginv2(loadbalancerv2.LoadBalancerPluginBaseV2,
             to_validate.extend([listener['default_tls_container_ref']])
             if 'sni_container_refs' in listener:
                 to_validate.extend(listener['sni_container_refs'])
-        elif curr_listener['provisioning_status'] == constants.ERROR:
+        elif curr_listener['provisioning_status'] == n_constants.ERROR:
             to_validate.extend(curr_listener['default_tls_container_id'])
             to_validate.extend([
                 container['tls_container_id'] for container in (
@@ -546,7 +550,7 @@ class LoadBalancerPluginv2(loadbalancerv2.LoadBalancerPluginBaseV2,
         elif not lb_id:
             raise sharedpools.ListenerMustHaveLoadbalancer()
         self.db.test_and_set_status(context, models.LoadBalancer, lb_id,
-                                    constants.PENDING_UPDATE)
+                                    n_constants.PENDING_UPDATE)
 
         try:
             if listener['protocol'] == lb_const.PROTOCOL_TERMINATED_HTTPS:
@@ -577,7 +581,7 @@ class LoadBalancerPluginv2(loadbalancerv2.LoadBalancerPluginBaseV2,
             self._check_listener_pool_lb_match(
                 context, id, default_pool_id)
         self.db.test_and_set_status(context, models.Listener, id,
-                                    constants.PENDING_UPDATE)
+                                    n_constants.PENDING_UPDATE)
         try:
             curr_listener = curr_listener_db.to_dict()
 
@@ -603,13 +607,13 @@ class LoadBalancerPluginv2(loadbalancerv2.LoadBalancerPluginBaseV2,
                 context,
                 models.LoadBalancer,
                 curr_listener_db.loadbalancer.id,
-                provisioning_status=constants.ACTIVE
+                provisioning_status=n_constants.ACTIVE
             )
             self.db.update_status(
                 context,
                 models.Listener,
                 curr_listener_db.id,
-                provisioning_status=constants.ACTIVE
+                provisioning_status=n_constants.ACTIVE
             )
             raise exc
 
@@ -631,7 +635,7 @@ class LoadBalancerPluginv2(loadbalancerv2.LoadBalancerPluginBaseV2,
                 id=old_listener.l7_policies[0].id,
                 entity_in_use=models.L7Policy.NAME)
         self.db.test_and_set_status(context, models.Listener, id,
-                                    constants.PENDING_DELETE)
+                                    n_constants.PENDING_DELETE)
         listener_db = self.db.get_listener(context, id)
 
         driver = self._get_driver_for_loadbalancer(
@@ -677,7 +681,7 @@ class LoadBalancerPluginv2(loadbalancerv2.LoadBalancerPluginBaseV2,
         del pool['listener_id']
         pool['listeners'] = []
         self.db.test_and_set_status(context, models.LoadBalancer,
-                                    lb_id, constants.PENDING_UPDATE)
+                                    lb_id, n_constants.PENDING_UPDATE)
         db_pool = self.db.create_pool(context, pool)
         for db_l in db_listeners:
             try:
@@ -701,7 +705,7 @@ class LoadBalancerPluginv2(loadbalancerv2.LoadBalancerPluginBaseV2,
             pool.get('session_persistence'))
         old_pool = self.db.get_pool(context, id)
         self.db.test_and_set_status(context, models.PoolV2, id,
-                                    constants.PENDING_UPDATE)
+                                    n_constants.PENDING_UPDATE)
         try:
             updated_pool = self.db.update_pool(context, id, pool)
         except Exception as exc:
@@ -726,7 +730,7 @@ class LoadBalancerPluginv2(loadbalancerv2.LoadBalancerPluginBaseV2,
                 id=old_pool.healthmonitor.id,
                 entity_in_use=models.PoolV2.NAME)
         self.db.test_and_set_status(context, models.PoolV2, id,
-                                    constants.PENDING_DELETE)
+                                    n_constants.PENDING_DELETE)
         db_pool = self.db.get_pool(context, id)
 
         driver = self._get_driver_for_loadbalancer(
@@ -751,7 +755,7 @@ class LoadBalancerPluginv2(loadbalancerv2.LoadBalancerPluginBaseV2,
         db_pool = self.db.get_pool(context, pool_id)
         self.db.test_and_set_status(context, models.LoadBalancer,
                                     db_pool.root_loadbalancer.id,
-                                    constants.PENDING_UPDATE)
+                                    n_constants.PENDING_UPDATE)
         try:
             member_db = self.db.create_pool_member(context, member, pool_id)
         except Exception as exc:
@@ -772,7 +776,7 @@ class LoadBalancerPluginv2(loadbalancerv2.LoadBalancerPluginBaseV2,
         member = member.get('member')
         old_member = self.db.get_pool_member(context, id)
         self.db.test_and_set_status(context, models.MemberV2, id,
-                                    constants.PENDING_UPDATE)
+                                    n_constants.PENDING_UPDATE)
         try:
             updated_member = self.db.update_pool_member(context, id, member)
         except Exception as exc:
@@ -792,7 +796,7 @@ class LoadBalancerPluginv2(loadbalancerv2.LoadBalancerPluginBaseV2,
     def delete_pool_member(self, context, id, pool_id):
         self._check_pool_exists(context, pool_id)
         self.db.test_and_set_status(context, models.MemberV2, id,
-                                    constants.PENDING_DELETE)
+                                    n_constants.PENDING_DELETE)
         db_member = self.db.get_pool_member(context, id)
 
         driver = self._get_driver_for_loadbalancer(
@@ -827,7 +831,7 @@ class LoadBalancerPluginv2(loadbalancerv2.LoadBalancerPluginBaseV2,
         db_pool = self.db.get_pool(context, pool_id)
         self.db.test_and_set_status(context, models.LoadBalancer,
                                     db_pool.root_loadbalancer.id,
-                                    constants.PENDING_UPDATE)
+                                    n_constants.PENDING_UPDATE)
         try:
             db_hm = self.db.create_healthmonitor_on_pool(context, pool_id,
                                                          healthmonitor)
@@ -846,7 +850,7 @@ class LoadBalancerPluginv2(loadbalancerv2.LoadBalancerPluginBaseV2,
         healthmonitor = healthmonitor.get('healthmonitor')
         old_hm = self.db.get_healthmonitor(context, id)
         self.db.test_and_set_status(context, models.HealthMonitorV2, id,
-                                    constants.PENDING_UPDATE)
+                                    n_constants.PENDING_UPDATE)
         try:
             updated_hm = self.db.update_healthmonitor(context, id,
                                                       healthmonitor)
@@ -866,7 +870,7 @@ class LoadBalancerPluginv2(loadbalancerv2.LoadBalancerPluginBaseV2,
 
     def delete_healthmonitor(self, context, id):
         self.db.test_and_set_status(context, models.HealthMonitorV2, id,
-                                    constants.PENDING_DELETE)
+                                    n_constants.PENDING_DELETE)
         db_hm = self.db.get_healthmonitor(context, id)
 
         driver = self._get_driver_for_loadbalancer(
@@ -911,7 +915,7 @@ class LoadBalancerPluginv2(loadbalancerv2.LoadBalancerPluginBaseV2,
         l7policy = l7policy.get('l7policy')
         old_l7policy = self.db.get_l7policy(context, id)
         self.db.test_and_set_status(context, models.L7Policy, id,
-                                    constants.PENDING_UPDATE)
+                                    n_constants.PENDING_UPDATE)
         try:
             updated_l7policy = self.db.update_l7policy(
                 context, id, l7policy)
@@ -937,7 +941,7 @@ class LoadBalancerPluginv2(loadbalancerv2.LoadBalancerPluginBaseV2,
 
     def delete_l7policy(self, context, id):
         self.db.test_and_set_status(context, models.L7Policy, id,
-                                    constants.PENDING_DELETE)
+                                    n_constants.PENDING_DELETE)
         l7policy_db = self.db.get_l7policy(context, id)
 
         if l7policy_db.attached_to_loadbalancer():
@@ -980,7 +984,7 @@ class LoadBalancerPluginv2(loadbalancerv2.LoadBalancerPluginBaseV2,
         rule = rule.get('rule')
         old_rule_db = self.db.get_l7policy_rule(context, id, l7policy_id)
         self.db.test_and_set_status(context, models.L7Rule, id,
-                                    constants.PENDING_UPDATE)
+                                    n_constants.PENDING_UPDATE)
         try:
             upd_rule_db = self.db.update_l7policy_rule(
                 context, id, rule, l7policy_id)
@@ -1009,7 +1013,7 @@ class LoadBalancerPluginv2(loadbalancerv2.LoadBalancerPluginBaseV2,
 
     def delete_l7policy_rule(self, context, id, l7policy_id):
         self.db.test_and_set_status(context, models.L7Rule, id,
-                                    constants.PENDING_DELETE)
+                                    n_constants.PENDING_DELETE)
         rule_db = self.db.get_l7policy_rule(context, id, l7policy_id)
 
         if rule_db.attached_to_loadbalancer():
@@ -1240,7 +1244,7 @@ class LoadBalancerPluginv2(loadbalancerv2.LoadBalancerPluginBaseV2,
     def _is_degraded(self, obj, exclude=None):
         exclude = exclude or []
         if "provisioning_status" not in exclude:
-            if obj.provisioning_status == constants.ERROR:
+            if obj.provisioning_status == n_constants.ERROR:
                 return True
         if "operating_status" not in exclude:
             if ((obj.operating_status != lb_const.ONLINE) and
