@@ -14,6 +14,11 @@ function load_conf_hook {
     _DEVSTACK_LOCAL_CONFIG_TAIL+=$'\n'"$(cat $GATE_HOOKS/$hook)"
 }
 
+# Work around a devstack issue:https://review.openstack.org/#/c/435106
+export DEVSTACK_LOCAL_CONFIG+="
+DEFAULT_IMAGE_NAME=cirros-0.3.5-x86_64-disk
+"
+
 export DEVSTACK_LOCAL_CONFIG+="
 enable_plugin neutron-lbaas https://git.openstack.org/openstack/neutron-lbaas
 enable_plugin barbican https://git.openstack.org/openstack/barbican
@@ -38,9 +43,7 @@ function _setup_octavia {
         "
     fi
 
-    if [ "$testenv" != "apiv1" ]; then
-        ENABLED_SERVICES+="octavia,o-cw,o-hk,o-hm,o-api,"
-    fi
+    ENABLED_SERVICES+="octavia,o-cw,o-hk,o-hm,o-api,"
     if [ "$testenv" = "apiv2" ]; then
         load_conf_hook apiv2
     fi
@@ -71,7 +74,7 @@ case "$testtype" in
         # Make sure lbaasv2 is listed as enabled for tempest
         load_conf_hook api_extensions
 
-        # These are not needed with either v1 or v2
+        # These are not needed
         ENABLED_SERVICES+="-c-api,-c-bak,-c-sch,-c-vol,-cinder,"
         ENABLED_SERVICES+="-s-account,-s-container,-s-object,-s-proxy,"
 
@@ -86,18 +89,14 @@ case "$testtype" in
             ENABLED_SERVICES+="-ceilometer-collector,"
         fi
 
-        if [ "$testenv" == "apiv1" ]; then
-            ENABLED_SERVICES+="q-lbaas,"
-        else
-            # Override enabled services, so we can turn on lbaasv2.
-            # While we're at it, disable cinder and swift, since we don't need them.
-            ENABLED_SERVICES+="q-lbaasv2,-q-lbaas,"
+        # Override enabled services, so we can turn on lbaasv2.
+        # While we're at it, disable cinder and swift, since we don't need them.
+        ENABLED_SERVICES+="q-lbaasv2,"
 
-            if [ "$lbaasdriver" = "namespace" ]; then
-                export DEVSTACK_LOCAL_CONFIG+="
+        if [ "$lbaasdriver" = "namespace" ]; then
+            export DEVSTACK_LOCAL_CONFIG+="
         NEUTRON_LBAAS_SERVICE_PROVIDERV2=LOADBALANCERV2:Haproxy:neutron_lbaas.drivers.haproxy.plugin_driver.HaproxyOnHostPluginDriver:default
         "
-             fi
         fi
 
         if [ "$lbaasdriver" = "octavia" ]; then
