@@ -17,6 +17,7 @@
 from oslo_utils import uuidutils
 from tempest import config
 from tempest.lib.common.utils import data_utils
+from tempest.lib import decorators
 from tempest.lib import exceptions as ex
 from tempest import test
 
@@ -50,9 +51,9 @@ class TestHealthMonitors(base.BaseAdminTestCase):
             vip_subnet_id=cls.subnet.get('id'))
         cls.listener = cls._create_listener(
             loadbalancer_id=cls.load_balancer.get('id'),
-            protocol='HTTP', protocol_port=80)
+            protocol=cls.listener_protocol, protocol_port=80)
         cls.pool = cls._create_pool(
-            protocol='HTTP', lb_algorithm='ROUND_ROBIN',
+            protocol=cls.pool_protocol, lb_algorithm='ROUND_ROBIN',
             listener_id=cls.listener.get('id'))
 
     @classmethod
@@ -64,8 +65,8 @@ class TestHealthMonitors(base.BaseAdminTestCase):
         Test if admin user can create health monitor with a missing tenant id
         field.
         """
-        hm = self._create_health_monitor(type='HTTP', delay=3, max_retries=10,
-                                         timeout=5,
+        hm = self._create_health_monitor(type=self.hm_protocol, delay=3,
+                                         max_retries=10, timeout=5,
                                          pool_id=self.pool.get('id'))
 
         admin_hm = self.health_monitors_client.get_health_monitor(hm.get('id'))
@@ -73,26 +74,24 @@ class TestHealthMonitors(base.BaseAdminTestCase):
         hm_tenant_id = hm.get('tenant_id')
         self.assertEqual(admin_tenant_id, hm_tenant_id)
 
-    @test.attr(type='negative')
+    @decorators.attr(type='negative')
     def test_create_health_monitor_empty_tenant_id_field(self):
         """
         Test with admin user creating health monitor with an empty tenant id
         field should fail.
         """
         self.assertRaises(ex.BadRequest, self._create_health_monitor,
-                          type='HTTP', delay=3, max_retries=10,
-                          timeout=5,
-                          pool_id=self.pool.get('id'),
-                          tenant_id="")
+                          type=self.hm_protocol, delay=3, max_retries=10,
+                          timeout=5, pool_id=self.pool.get('id'), tenant_id="")
 
-    @test.attr(type='smoke')
+    @decorators.attr(type='smoke')
     def test_create_health_monitor_for_another_tenant_id_field(self):
         """Test with admin user create health monitor for another tenant id.
         """
 
         tenantid = uuidutils.generate_uuid()
-        hm = self._create_health_monitor(type='HTTP', delay=3, max_retries=10,
-                                         timeout=5,
+        hm = self._create_health_monitor(type=self.hm_protocol, delay=3,
+                                         max_retries=10, timeout=5,
                                          pool_id=self.pool.get('id'),
                                          tenant_id=tenantid)
 
