@@ -13,6 +13,7 @@
 #    under the License.
 
 from tempest.lib.common.utils import data_utils
+from tempest.lib import decorators
 from tempest.lib import exceptions as ex
 from tempest import test
 
@@ -45,11 +46,11 @@ class TestHealthMonitors(base.BaseTestCase):
             vip_subnet_id=cls.subnet.get('id'))
         cls.listener = cls._create_listener(
             loadbalancer_id=cls.load_balancer.get('id'),
-            protocol='HTTP', protocol_port=80)
+            protocol=cls.listener_protocol, protocol_port=80)
         cls.pool = cls._create_pool(
-            protocol='HTTP', lb_algorithm='ROUND_ROBIN',
+            protocol=cls.pool_protocol, lb_algorithm='ROUND_ROBIN',
             listener_id=cls.listener.get('id'))
-        cls.create_basic_hm_kwargs = {'type': 'HTTP', 'delay': 3,
+        cls.create_basic_hm_kwargs = {'type': cls.hm_protocol, 'delay': 3,
                                       'max_retries': 10, 'timeout': 5,
                                       'pool_id': cls.pool.get('id')}
 
@@ -62,15 +63,15 @@ class TestHealthMonitors(base.BaseTestCase):
         hm_list = self.health_monitors_client.list_health_monitors()
         self.assertIn(hm, hm_list)
 
-    @test.attr(type='smoke')
+    @decorators.attr(type='smoke')
     def test_list_health_monitors_two(self):
         hm1 = self._create_health_monitor(**self.create_basic_hm_kwargs)
         new_listener = self._create_listener(
             loadbalancer_id=self.load_balancer.get('id'),
-            protocol='HTTP', protocol_port=88)
+            protocol=self.listener_protocol, protocol_port=88)
         self.addCleanup(self._delete_listener, new_listener.get('id'))
         new_pool = self._create_pool(
-            protocol='HTTP', lb_algorithm='ROUND_ROBIN',
+            protocol=self.pool_protocol, lb_algorithm='ROUND_ROBIN',
             listener_id=new_listener.get('id'))
         self.addCleanup(self._delete_pool, new_pool.get('id'))
         hm2 = self._create_health_monitor(
@@ -84,13 +85,13 @@ class TestHealthMonitors(base.BaseTestCase):
         self.assertIn(hm1, hm_list)
         self.assertIn(hm2, hm_list)
 
-    @test.attr(type='smoke')
+    @decorators.attr(type='smoke')
     def test_get_health_monitor(self):
         hm = self._create_health_monitor(**self.create_basic_hm_kwargs)
         hm_test = self.health_monitors_client.get_health_monitor(hm.get('id'))
         self.assertEqual(hm, hm_test)
 
-    @test.attr(type='smoke')
+    @decorators.attr(type='smoke')
     def test_create_health_monitor(self):
         new_hm = self._create_health_monitor(**self.create_basic_hm_kwargs)
         hm = self.health_monitors_client.get_health_monitor(new_hm.get('id'))
@@ -98,7 +99,7 @@ class TestHealthMonitors(base.BaseTestCase):
 
     def test_create_health_monitor_missing_attribute(self):
         self.assertRaises(ex.BadRequest, self._create_health_monitor,
-                          type='HTTP', delay=3, max_retries=10,
+                          type=self.hm_protocol, delay=3, max_retries=10,
                           pool_id=self.pool.get('id'))
 
     def test_create_health_monitor_missing_required_field_type(self):
@@ -114,7 +115,7 @@ class TestHealthMonitors(base.BaseTestCase):
         missing
         """
         self.assertRaises(ex.BadRequest, self._create_health_monitor,
-                          type='HTTP', max_retries=10, timeout=5,
+                          type=self.hm_protocol, max_retries=10, timeout=5,
                           pool_id=self.pool.get('id'))
 
     def test_create_health_monitor_missing_required_field_timeout(self):
@@ -122,7 +123,7 @@ class TestHealthMonitors(base.BaseTestCase):
         missing
         """
         self.assertRaises(ex.BadRequest, self._create_health_monitor,
-                          type='HTTP', delay=3, max_retries=10,
+                          type=self.hm_protocol, delay=3, max_retries=10,
                           pool_id=self.pool.get('id'))
 
     def test_create_health_monitor_missing_required_field_max_retries(self):
@@ -130,7 +131,7 @@ class TestHealthMonitors(base.BaseTestCase):
         missing
         """
         self.assertRaises(ex.BadRequest, self._create_health_monitor,
-                          type='HTTP', delay=3, timeout=5,
+                          type=self.hm_protocol, delay=3, timeout=5,
                           pool_id=self.pool.get('id'))
 
     def test_create_health_monitor_missing_required_field_pool_id(self):
@@ -138,7 +139,8 @@ class TestHealthMonitors(base.BaseTestCase):
         missing
         """
         self.assertRaises(ex.BadRequest, self._create_health_monitor,
-                          type='HTTP', delay=3, max_retries=10, timeout=5)
+                          type=self.hm_protocol, delay=3, max_retries=10,
+                          timeout=5)
 
     def test_create_health_monitor_missing_admin_state_up(self):
         """Test if a non_admin user can create a health monitor with
@@ -153,6 +155,9 @@ class TestHealthMonitors(base.BaseTestCase):
         """Test if a non_admin user can create a health monitor with
         http_method missing
         """
+        if self.hm_protocol != 'HTTP':
+            msg = "health monitor protocol must be HTTP for http_method"
+            raise self.skipException(msg)
         hm = self._create_health_monitor(**self.create_basic_hm_kwargs)
 
         hm_test = self.health_monitors_client.get_health_monitor(hm.get('id'))
@@ -163,6 +168,9 @@ class TestHealthMonitors(base.BaseTestCase):
         """Test if a non_admin user can create a health monitor with
         url_path missing
         """
+        if self.hm_protocol != 'HTTP':
+            msg = "health monitor protocol must be HTTP for url_path"
+            raise self.skipException(msg)
         hm = self._create_health_monitor(**self.create_basic_hm_kwargs)
         hm_test = self.health_monitors_client.get_health_monitor(hm.get('id'))
         self.assertEqual(hm, hm_test)
@@ -172,173 +180,181 @@ class TestHealthMonitors(base.BaseTestCase):
         """Test if a non_admin user can create a health monitor with
         expected_codes missing
         """
+        if self.hm_protocol != 'HTTP':
+            msg = "health monitor protocol must be HTTP for expected_codes"
+            raise self.skipException(msg)
         hm = self._create_health_monitor(**self.create_basic_hm_kwargs)
 
         hm_test = self.health_monitors_client.get_health_monitor(hm.get('id'))
         self.assertEqual(hm, hm_test)
         self.assertEqual('200', hm_test.get('expected_codes'))
 
-    @test.attr(type='negative')
+    @decorators.attr(type='negative')
     def test_create_health_monitor_invalid_tenant_id(self):
         """Test create health monitor with invalid tenant_id"""
         self.assertRaises(ex.BadRequest, self._create_health_monitor,
                           tenant_id='blah',
-                          type='HTTP', delay=3, max_retries=10, timeout=5,
-                          pool_id=self.pool.get('id'))
+                          type=self.hm_protocol, delay=3, max_retries=10,
+                          timeout=5, pool_id=self.pool.get('id'))
 
-    @test.attr(type='negative')
+    @decorators.attr(type='negative')
     def test_create_health_monitor_invalid_type(self):
         """Test create health monitor with invalid type"""
         self.assertRaises(ex.BadRequest, self._create_health_monitor,
                           type='blah', delay=3, max_retries=10, timeout=5,
                           pool_id=self.pool.get('id'))
 
-    @test.attr(type='negative')
+    @decorators.attr(type='negative')
     def test_create_health_monitor_invalid_delay(self):
         """Test create health monitor with invalid delay"""
         self.assertRaises(ex.BadRequest, self._create_health_monitor,
-                          type='HTTP', delay='blah', max_retries=10, timeout=5,
-                          pool_id=self.pool.get('id'))
+                          type=self.hm_protocol, delay='blah', max_retries=10,
+                          timeout=5, pool_id=self.pool.get('id'))
 
-    @test.attr(type='negative')
+    @decorators.attr(type='negative')
     def test_create_health_monitor_invalid_max_retries(self):
         """Test create health monitor with invalid max_retries"""
         self.assertRaises(ex.BadRequest, self._create_health_monitor,
-                          type='HTTP', delay=3, max_retries='blah', timeout=5,
-                          pool_id=self.pool.get('id'))
+                          type=self.hm_protocol, delay=3, max_retries='blah',
+                          timeout=5, pool_id=self.pool.get('id'))
 
-    @test.attr(type='negative')
+    @decorators.attr(type='negative')
     def test_create_health_monitor_invalid_timeout(self):
         """Test create health monitor with invalid timeout"""
         self.assertRaises(ex.BadRequest, self._create_health_monitor,
-                          type='HTTP', delay=3, max_retries=10, timeout='blah',
-                          pool_id=self.pool.get('id'))
+                          type=self.hm_protocol, delay=3, max_retries=10,
+                          timeout='blah', pool_id=self.pool.get('id'))
 
-    @test.attr(type='negative')
+    @decorators.attr(type='negative')
     def test_create_health_monitor_invalid_pool_id(self):
         """Test create health monitor with invalid pool id"""
         self.assertRaises(ex.BadRequest, self._create_health_monitor,
-                          type='HTTP', delay=3, max_retries=10, timeout=5,
-                          pool_id='blah')
+                          type=self.hm_protocol, delay=3, max_retries=10,
+                          timeout=5, pool_id='blah')
 
-    @test.attr(type='negative')
+    @decorators.attr(type='negative')
     def test_create_health_monitor_invalid_admin_state_up(self):
         """Test if a non_admin user can create a health monitor with invalid
         admin_state_up
         """
         self.assertRaises(ex.BadRequest, self._create_health_monitor,
-                          type='HTTP', delay=3, max_retries=10, timeout=5,
-                          pool_id=self.pool.get('id'), admin_state_up='blah'
-                          )
+                          type=self.hm_protocol, delay=3, max_retries=10,
+                          timeout=5, pool_id=self.pool.get('id'),
+                          admin_state_up='blah')
 
-    @test.attr(type='negative')
+    @decorators.attr(type='negative')
     def test_create_health_monitor_invalid_expected_codes(self):
         """Test if a non_admin user can create a health monitor with invalid
         expected_codes
         """
         self.assertRaises(ex.BadRequest, self._create_health_monitor,
-                          type='HTTP', delay=3, max_retries=10, timeout=5,
-                          pool_id=self.pool.get('id'), expected_codes='blah'
-                          )
+                          type=self.hm_protocol, delay=3, max_retries=10,
+                          timeout=5, pool_id=self.pool.get('id'),
+                          expected_codes='blah')
 
-    @test.attr(type='negative')
+    @decorators.attr(type='negative')
     def test_create_health_monitor_invalid_url_path(self):
         """Test if a non_admin user can create a health monitor with invalid
         url_path
         """
         self.assertRaises(ex.BadRequest, self._create_health_monitor,
-                          type='HTTP', delay=3, max_retries=10, timeout=5,
-                          pool_id=self.pool.get('id'), url_path='blah'
-                          )
+                          type=self.hm_protocol, delay=3, max_retries=10,
+                          timeout=5, pool_id=self.pool.get('id'),
+                          url_path='blah')
 
-    @test.attr(type='negative')
+    @decorators.attr(type='negative')
     def test_create_health_monitor_invalid_http_method(self):
         """Test if a non_admin user can create a health monitor with invalid
         http_method
         """
         self.assertRaises(ex.BadRequest, self._create_health_monitor,
-                          type='HTTP', delay=3, max_retries=10, timeout=5,
-                          pool_id=self.pool.get('id'), http_method='blah')
+                          type=self.hm_protocol, delay=3, max_retries=10,
+                          timeout=5, pool_id=self.pool.get('id'),
+                          http_method='blah')
 
-    @test.attr(type='negative')
+    @decorators.attr(type='negative')
     def test_create_health_monitor_empty_type(self):
         """Test create health monitor with empty type"""
         self.assertRaises(ex.BadRequest, self._create_health_monitor,
                           type='', delay=3, max_retries=10, timeout=5,
                           pool_id=self.pool.get('id'))
 
-    @test.attr(type='negative')
+    @decorators.attr(type='negative')
     def test_create_health_monitor_empty_delay(self):
         """Test create health monitor with empty delay"""
         self.assertRaises(ex.BadRequest, self._create_health_monitor,
-                          type='HTTP', delay='', max_retries=10, timeout=5,
-                          pool_id=self.pool.get('id'))
+                          type=self.hm_protocol, delay='', max_retries=10,
+                          timeout=5, pool_id=self.pool.get('id'))
 
-    @test.attr(type='negative')
+    @decorators.attr(type='negative')
     def test_create_health_monitor_empty_timeout(self):
         """Test create health monitor with empty timeout"""
         self.assertRaises(ex.BadRequest, self._create_health_monitor,
-                          type='HTTP', delay=3, max_retries=10, timeout='',
-                          pool_id=self.pool.get('id'))
+                          type=self.hm_protocol, delay=3, max_retries=10,
+                          timeout='', pool_id=self.pool.get('id'))
 
-    @test.attr(type='negative')
+    @decorators.attr(type='negative')
     def test_create_health_monitor_empty_max_retries(self):
         """Test create health monitor with empty max_retries"""
         self.assertRaises(ex.BadRequest, self._create_health_monitor,
-                          type='HTTP', delay=3, max_retries='', timeout=5,
-                          pool_id=self.pool.get('id'))
+                          type=self.hm_protocol, delay=3, max_retries='',
+                          timeout=5, pool_id=self.pool.get('id'))
 
-    @test.attr(type='negative')
+    @decorators.attr(type='negative')
     def test_create_health_monitor_empty_max_pool_id(self):
         """Test create health monitor with empty pool_id"""
         self.assertRaises(ex.BadRequest, self._create_health_monitor,
-                          type='HTTP', delay=3, max_retries=10, timeout=5,
-                          pool_id='')
+                          type=self.hm_protocol, delay=3, max_retries=10,
+                          timeout=5, pool_id='')
 
-    @test.attr(type='negative')
+    @decorators.attr(type='negative')
     def test_create_health_monitor_empty_max_admin_state_up(self):
         """Test create health monitor with empty admin_state_up"""
         self.assertRaises(ex.BadRequest, self._create_health_monitor,
-                          type='HTTP', delay=3, max_retries=10, timeout=5,
-                          pool_id=self.pool.get('id'), admin_state_up='')
+                          type=self.hm_protocol, delay=3, max_retries=10,
+                          timeout=5, pool_id=self.pool.get('id'),
+                          admin_state_up='')
 
-    @test.attr(type='negative')
+    @decorators.attr(type='negative')
     def test_create_health_monitor_empty_max_http_method(self):
         """Test create health monitor with empty http_method"""
         self.assertRaises(ex.BadRequest, self._create_health_monitor,
-                          type='HTTP', delay=3, max_retries=10, timeout=5,
-                          pool_id=self.pool.get('id'), http_method='')
+                          type=self.hm_protocol, delay=3, max_retries=10,
+                          timeout=5, pool_id=self.pool.get('id'),
+                          http_method='')
 
-    @test.attr(type='negative')
+    @decorators.attr(type='negative')
     def test_create_health_monitor_empty_max_url_path(self):
         """Test create health monitor with empty url_path"""
         self.assertRaises(ex.BadRequest, self._create_health_monitor,
-                          type='HTTP', delay=3, max_retries=10, timeout=5,
-                          pool_id=self.pool.get('id'), url_path='')
+                          type=self.hm_protocol, delay=3, max_retries=10,
+                          timeout=5, pool_id=self.pool.get('id'), url_path='')
 
-    @test.attr(type='negative')
+    @decorators.attr(type='negative')
     def test_create_health_monitor_empty_expected_codes(self):
         """Test create health monitor with empty expected_codes"""
         self.assertRaises(ex.BadRequest, self._create_health_monitor,
-                          type='HTTP', delay=3, max_retries=10, timeout=5,
-                          pool_id=self.pool.get('id'), expected_codes='')
+                          type=self.hm_protocol, delay=3, max_retries=10,
+                          timeout=5, pool_id=self.pool.get('id'),
+                          expected_codes='')
 
-    @test.attr(type='negative')
+    @decorators.attr(type='negative')
     def test_create_health_monitor_invalid_attribute(self):
         self.assertRaises(ex.BadRequest, self._create_health_monitor,
-                          type='HTTP', delay=3, max_retries='twenty one',
+                          type=self.hm_protocol, delay=3,
+                          max_retries='twenty one',
                           pool_id=self.pool.get('id'))
 
-    @test.attr(type='negative')
+    @decorators.attr(type='negative')
     def test_create_health_monitor_extra_attribute(self):
         self.assertRaises(ex.BadRequest, self._create_health_monitor,
-                          type='HTTP', delay=3, max_retries=10,
+                          type=self.hm_protocol, delay=3, max_retries=10,
                           pool_id=self.pool.get('id'), subnet_id=10)
 
-    @test.attr(type='smoke')
+    @decorators.attr(type='smoke')
     def test_update_health_monitor(self):
-        hm = self._create_health_monitor(type='HTTP', delay=3, max_retries=10,
-                                         timeout=5,
+        hm = self._create_health_monitor(type=self.hm_protocol, delay=3,
+                                         max_retries=10, timeout=5,
                                          pool_id=self.pool.get('id'))
         max_retries = 1
         new_hm = self._update_health_monitor(
@@ -388,105 +404,105 @@ class TestHealthMonitors(base.BaseTestCase):
         self.assertEqual(hm.get('expected_codes'),
                          new_hm.get('expected_codes'))
 
-    @test.attr(type='negative')
+    @decorators.attr(type='negative')
     def test_update_health_monitor_invalid_attribute(self):
         hm = self._create_health_monitor(**self.create_basic_hm_kwargs)
         self.assertRaises(ex.BadRequest,
                           self._update_health_monitor,
                           hm.get('id'), max_retries='blue')
 
-    @test.attr(type='negative')
+    @decorators.attr(type='negative')
     def test_update_health_monitor_invalid_admin_state_up(self):
         hm = self._create_health_monitor(**self.create_basic_hm_kwargs)
         self.assertRaises(ex.BadRequest,
                           self._update_health_monitor,
                           hm.get('id'), admin_state_up='blah')
 
-    @test.attr(type='negative')
+    @decorators.attr(type='negative')
     def test_update_health_monitor_invalid_delay(self):
         hm = self._create_health_monitor(**self.create_basic_hm_kwargs)
         self.assertRaises(ex.BadRequest,
                           self._update_health_monitor,
                           hm.get('id'), delay='blah')
 
-    @test.attr(type='negative')
+    @decorators.attr(type='negative')
     def test_update_health_monitor_invalid_timeout(self):
         hm = self._create_health_monitor(**self.create_basic_hm_kwargs)
         self.assertRaises(ex.BadRequest,
                           self._update_health_monitor,
                           hm.get('id'), timeout='blah')
 
-    @test.attr(type='negative')
+    @decorators.attr(type='negative')
     def test_update_health_monitor_invalid_max_retries(self):
         hm = self._create_health_monitor(**self.create_basic_hm_kwargs)
         self.assertRaises(ex.BadRequest,
                           self._update_health_monitor,
                           hm.get('id'), max_retries='blah')
 
-    @test.attr(type='negative')
+    @decorators.attr(type='negative')
     def test_update_health_monitor_invalid_http_method(self):
         hm = self._create_health_monitor(**self.create_basic_hm_kwargs)
         self.assertRaises(ex.BadRequest,
                           self._update_health_monitor,
                           hm.get('id'), http_method='blah')
 
-    @test.attr(type='negative')
+    @decorators.attr(type='negative')
     def test_update_health_monitor_invalid_url_path(self):
         hm = self._create_health_monitor(**self.create_basic_hm_kwargs)
         self.assertRaises(ex.BadRequest,
                           self._update_health_monitor,
                           hm.get('id'), url_path='blah')
 
-    @test.attr(type='negative')
+    @decorators.attr(type='negative')
     def test_update_health_monitor_invalid_expected_codes(self):
         hm = self._create_health_monitor(**self.create_basic_hm_kwargs)
         self.assertRaises(ex.BadRequest,
                           self._update_health_monitor,
                           hm.get('id'), expected_codes='blah')
 
-    @test.attr(type='negative')
+    @decorators.attr(type='negative')
     def test_update_health_monitor_empty_admin_state_up(self):
         hm = self._create_health_monitor(**self.create_basic_hm_kwargs)
         self.assertRaises(ex.BadRequest,
                           self._update_health_monitor,
                           hm.get('id'), admin_state_up='')
 
-    @test.attr(type='negative')
+    @decorators.attr(type='negative')
     def test_update_health_monitor_empty_delay(self):
         hm = self._create_health_monitor(**self.create_basic_hm_kwargs)
         self.assertRaises(ex.BadRequest,
                           self._update_health_monitor,
                           hm.get('id'), empty_delay='')
 
-    @test.attr(type='negative')
+    @decorators.attr(type='negative')
     def test_update_health_monitor_empty_timeout(self):
         hm = self._create_health_monitor(**self.create_basic_hm_kwargs)
         self.assertRaises(ex.BadRequest,
                           self._update_health_monitor,
                           hm.get('id'), timeout='')
 
-    @test.attr(type='negative')
+    @decorators.attr(type='negative')
     def test_update_health_monitor_empty_max_retries(self):
         hm = self._create_health_monitor(**self.create_basic_hm_kwargs)
         self.assertRaises(ex.BadRequest,
                           self._update_health_monitor,
                           hm.get('id'), max_retries='')
 
-    @test.attr(type='negative')
+    @decorators.attr(type='negative')
     def test_update_health_monitor_empty_empty_http_method(self):
         hm = self._create_health_monitor(**self.create_basic_hm_kwargs)
         self.assertRaises(ex.BadRequest,
                           self._update_health_monitor,
                           hm.get('id'), http_method='')
 
-    @test.attr(type='negative')
+    @decorators.attr(type='negative')
     def test_update_health_monitor_empty_url_path(self):
         hm = self._create_health_monitor(**self.create_basic_hm_kwargs)
         self.assertRaises(ex.BadRequest,
                           self._update_health_monitor,
                           hm.get('id'), http_method='')
 
-    @test.attr(type='negative')
+    @decorators.attr(type='negative')
     def test_update_health_monitor_empty_expected_codes(self):
         hm = self._create_health_monitor(**self.create_basic_hm_kwargs)
         self.assertRaises(ex.BadRequest,
@@ -499,10 +515,10 @@ class TestHealthMonitors(base.BaseTestCase):
                           self._update_health_monitor,
                           hm.get('id'), protocol='UDP')
 
-    @test.attr(type='smoke')
+    @decorators.attr(type='smoke')
     def test_delete_health_monitor(self):
-        hm = self._create_health_monitor(cleanup=False, type='HTTP', delay=3,
-                                         max_retries=10, timeout=5,
+        hm = self._create_health_monitor(cleanup=False, type=self.hm_protocol,
+                                         delay=3, max_retries=10, timeout=5,
                                          pool_id=self.pool.get('id'))
         self._delete_health_monitor(hm.get('id'))
         self.assertRaises(ex.NotFound,
