@@ -18,7 +18,7 @@ import socket
 
 import mock
 from neutron.agent.linux import external_process
-from neutron.plugins.common import constants
+from neutron_lib import constants
 from neutron_lib import exceptions
 
 from neutron_lbaas.drivers.haproxy import namespace_driver
@@ -42,7 +42,7 @@ class TestHaproxyNSDriver(base.BaseTestCase):
         self.ensure_dir = mock.patch.object(fileutils, 'ensure_tree').start()
         self._process_monitor = mock.Mock()
         with mock.patch(
-                'neutron.common.utils.load_class_by_alias_or_classname'):
+                'neutron_lib.utils.runtime.load_class_by_alias_or_classname'):
             self.driver = namespace_driver.HaproxyNSDriver(
                 conf,
                 self.rpc_mock,
@@ -174,11 +174,15 @@ class TestHaproxyNSDriver(base.BaseTestCase):
                            '\n')
         with mock.patch.object(self.driver, '_get_state_file_path') as gsp, \
                 mock.patch('socket.socket') as mocket, \
-                mock.patch('os.path.exists') as path_exists:
+                mock.patch('os.path.exists') as path_exists, \
+                mock.patch.object(data_models.LoadBalancer, 'from_dict') \
+                as lb_from_dict, \
+                mock.patch.object(self.driver, '_is_active') as is_active:
             gsp.side_effect = lambda x, y, z: '/pool/' + y
             path_exists.return_value = True
             mocket.return_value = mocket
-            mocket.recv.return_value = raw_stats
+            mocket.recv.return_value = raw_stats.encode('utf-8')
+            is_active.return_value = True
 
             exp_stats = {'connection_errors': '0',
                          'active_connections': '3',
@@ -206,15 +210,57 @@ class TestHaproxyNSDriver(base.BaseTestCase):
             stats = self.driver.get_stats(self.lb.id)
             self.assertEqual(exp_stats, stats)
 
-            mocket.recv.return_value = raw_stats_empty
+            mocket.recv.return_value = raw_stats_empty.encode('utf-8')
             self.assertEqual({'members': {}},
                              self.driver.get_stats(self.lb.id))
 
+            path_exists.return_value = False
+            is_active.return_value = True
+            listener = data_models.Listener(
+                provisioning_status=constants.PENDING_CREATE,
+                admin_state_up=True)
+            self.lb.listeners.append(listener)
+            lb_from_dict.return_value = \
+                data_models.LoadBalancer.from_dict(self.lb)
+
+            self.lb.listeners.append(listener)
+            self.assertEqual({}, self.driver.get_stats(self.lb.id))
+
             path_exists.return_value = False
             mocket.reset_mock()
+            is_active.return_value = False
             self.assertEqual({}, self.driver.get_stats(self.lb.id))
             self.assertFalse(mocket.called)
 
+    def test_is_active(self):
+        # test no listeners
+        ret_val = self.driver._is_active(self.lb)
+        self.assertFalse(ret_val)
+
+        # test bad VIP status
+        listener = data_models.Listener(
+            provisioning_status=constants.PENDING_CREATE,
+            admin_state_up=True)
+        self.lb.listeners.append(listener)
+        self.lb.vip_port.status = constants.DOWN
+        ret_val = self.driver._is_active(self.lb)
+        self.assertFalse(ret_val)
+        self.lb.vip_port.status = constants.PENDING_CREATE
+        self.lb.vip_port.admin_state_up = False
+        ret_val = self.driver._is_active(self.lb)
+        self.assertFalse(ret_val)
+
+        # test bad LB status
+        self.lb.vip_port.admin_state_up = True
+        self.lb.operating_status = 'OFFLINE'
+        ret_val = self.driver._is_active(self.lb)
+        self.assertFalse(ret_val)
+
+        # test everything good
+        self.lb.operating_status = 'ONLINE'
+        ret_val = self.driver._is_active(self.lb)
+        self.assertTrue(ret_val)
+
     def test_deploy_instance(self):
         self.driver.deployable = mock.Mock(return_value=False)
         self.driver.exists = mock.Mock(return_value=True)
@@ -437,7 +483,7 @@ class TestHaproxyNSDriver(base.BaseTestCase):
             namespace=namespace_driver.get_ns_name(self.lb.id))
         mock_ns.netns.execute.assert_called_once_with(
             ['haproxy', '-f', conf_dir % 'haproxy.conf', '-p',
-             conf_dir % 'haproxy.pid'], addl_env=None, run_as_root=False)
+             conf_dir % 'haproxy.pid'], addl_env=None, run_as_root=True)
         self.assertIn(self.lb.id, self.driver.deployed_loadbalancers)
         self.assertEqual(self.lb,
                          self.driver.deployed_loadbalancers[self.lb.id])
